@@ -346,7 +346,7 @@ class ReferencedBySelectionProxyDb(ProxyDbBase):
         for tag in note.text.get_tags():
             if tag.name == 'Link':
                 if tag.value.startswith("gramps://"):
-                    obj_class, prop, value = tag.value[9:].split("/")
+                    obj_class, prop, value = tag.value[9:].split("/", 2)
                     if obj_class == "Media":         # bug6493
                         obj_class = "Media"
                     if prop == "handle":
