@@ -32,7 +32,6 @@ File and folder related utility functions
 import os
 import sys
 import shutil
-import io
 import hashlib
 import logging
 LOG = logging.getLogger(".gen.utils.file")
@@ -42,8 +41,8 @@ LOG = logging.getLogger(".gen.utils.file")
 # Gramps modules
 #
 #-------------------------------------------------------------------------
-from ..constfunc import win, mac, conv_to_unicode, get_env_var
-from ..const import TEMP_DIR, USER_HOME, GRAMPS_LOCALE as glocale
+from ..constfunc import win, mac, get_env_var
+from ..const import TEMP_DIR, USER_HOME, ENV, GRAMPS_LOCALE as glocale
 
 #-------------------------------------------------------------------------
 #
@@ -62,7 +61,7 @@ def find_file( filename):
     try:
         if os.path.isfile(filename):
             return(filename)
-    except UnicodeError:
+    except UnicodeError as err:
         LOG.error("Filename %s raised a Unicode Error %s.", repr(filename), err)
 
     LOG.debug("Filename %s not found.", repr(filename))
@@ -138,22 +137,66 @@ def relative_path(original, base):
     base_list = [_f for _f in base_list if _f]
     target_list = [_f for _f in target_list if _f]
     i = -1
+    # base path is normcase (lower case on Windows) so compare target in lower
+    # on Windows as well
     for i in range(min(len(base_list), len(target_list))):
-        if base_list[i] != target_list[i]: break
+        if win():
+            if base_list[i].lower() != target_list[i].lower():
+                break
+        else:
+            if base_list[i] != target_list[i]:
+                break
     else:
         #if break did not happen we are here at end, and add 1.
         i += 1
-    rel_list = [os.pardir] * (len(base_list)-i) + target_list[i:]
+    rel_list = [os.pardir] * (len(base_list) - i) + target_list[i:]
     return os.path.join(*rel_list)
 
+def expand_path(path, normalize = True):
+    """
+    Expand environment variables in a path
+    Uses both the environment variables and the Gramps environment
+    The expansion uses the str.format, e.g. "~/{GRAMPSHOME}/{VERSION}/filename.txt"
+    We make the assumption that the user will not use a path that contain variable names
+    (it is technically possible to use characters "{", "}" in  paths)
+    """
+    environment = dict(os.environ)
+    environment.update(ENV)
+    if not 'GRAMPSHOME' in environment:
+        environment['GRAMPSHOME'] = USER_HOME
+    path = path.format(**environment)
+    if normalize:
+        path = os.path.normcase(os.path.normpath(os.path.abspath(path)))
+    return path
+
 def media_path(db):
     """
     Given a database, return the mediapath to use as basedir for media
     """
     mpath = db.get_mediapath()
+    return expand_media_path(mpath, db)
+
+def expand_media_path(mpath, db):
+    """
+    Normalize a mediapath:
+     - Relative mediapath are considered as relative to the database
+     - Expand variables, see expand_path
+     - Convert to absolute path
+     - Convert slashes and case (on Windows)
+    """
+    # Use home dir if no media_path specified
     if mpath is None:
-        #use home dir
-        mpath = USER_HOME
+        mpath = os.path.abspath(USER_HOME)
+    # Expand environment variables
+    mpath = expand_path(mpath, False)
+    # Relative mediapath are considered as relative to the database
+    if not os.path.isabs(mpath):
+        basepath = db.get_save_path()
+        if not basepath:
+            basepath = USER_HOME
+        mpath = os.path.join(os.path.abspath(basepath), mpath)
+    # Normalize path
+    mpath = os.path.normcase(os.path.normpath(os.path.abspath(mpath)))
     return mpath
 
 def media_path_full(db, filename):
@@ -185,16 +228,40 @@ def search_for(name):
                 return 1
     return 0
 
+
+def where_is(name):
+    """ This command is similar to the Linux "whereis -b file" command.
+    It looks for an executable file (name) in the PATH python is using, as
+    well as several likely other paths.  It returns the first file found,
+    or an empty string if not found.
+    """
+    paths = set(os.environ['PATH'].split(os.pathsep))
+    if not win():
+        paths.update(("/bin", "/usr/bin", "/usr/local/bin", "/opt/local/bin",
+                      "/opt/bin"))
+    for i in paths:
+        fname = os.path.join(i, name)
+        if os.access(fname, os.X_OK) and not os.path.isdir(fname):
+            return fname
+    return ""
+
+
 def create_checksum(full_path):
     """
     Create a md5 hash for the given file.
     """
     full_path = os.path.normpath(full_path)
+    md5 = hashlib.md5()
     try:
-        with io.open(full_path, 'rb') as media_file:
-            md5sum = hashlib.md5(media_file.read()).hexdigest()
+        with open(full_path, 'rb') as media_file:
+            while True:
+                buf = media_file.read(65536)
+                if not buf:
+                    break
+                md5.update(buf)
+        md5sum = md5.hexdigest()
     except IOError:
-            md5sum = ''
+        md5sum = ''
     except UnicodeEncodeError:
-            md5sum = ''
+        md5sum = ''
     return md5sum
