@@ -15,7 +15,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 """
@@ -29,7 +29,7 @@ Provide merge capabilities for notes.
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
-from gramps.gen.const import URL_MANUAL_PAGE
+from gramps.gen.const import URL_MANUAL_SECT3
 from ..display import display_help
 from ..managedwindow import ManagedWindow
 from ..widgets.styledtextbuffer import StyledTextBuffer
@@ -40,8 +40,7 @@ from gramps.gen.merge import MergeNoteQuery
 # Gramps constants
 #
 #-------------------------------------------------------------------------
-WIKI_HELP_PAGE = '%s_-_Entering_and_Editing_Data:_Detailed_-_part_3' % \
-    URL_MANUAL_PAGE
+WIKI_HELP_PAGE = URL_MANUAL_SECT3
 WIKI_HELP_SEC = _('manual|Merge_Notes')
 _GLADE_FILE = 'mergenote.glade'
 
@@ -54,8 +53,8 @@ class MergeNote(ManagedWindow):
     """
     Displays a dialog box that allows two notes to be combined into one.
     """
-    def __init__(self, dbstate, uistate, handle1, handle2):
-        ManagedWindow.__init__(self, uistate, [], self.__class__)
+    def __init__(self, dbstate, uistate, track, handle1, handle2):
+        ManagedWindow.__init__(self, uistate, track, self.__class__)
         self.dbstate = dbstate
         database = dbstate.db
         self.no1 = database.get_note_from_handle(handle1)
@@ -65,6 +64,7 @@ class MergeNote(ManagedWindow):
         self.set_window(self._gladeobj.toplevel,
                         self.get_widget("note_title"),
                         _("Merge Notes"))
+        self.setup_configs('interface.merge-note', 600, 250)
 
         # Detailed selection widgets
         text1 = self.no1.get_styledtext()
@@ -159,9 +159,6 @@ class MergeNote(ManagedWindow):
         else:
             phoenix = self.no2
             titanic = self.no1
-            # Add second handle to history so that when merge is complete, 
-            # phoenix is the selected row.
-            self.uistate.set_active(phoenix.get_handle(), 'Note')
 
         if self.get_widget("text_btn1").get_active() ^ use_handle1:
             phoenix.set_styledtext(titanic.get_styledtext())
@@ -174,4 +171,7 @@ class MergeNote(ManagedWindow):
 
         query = MergeNoteQuery(self.dbstate, phoenix, titanic)
         query.execute()
+        # Add the selected handle to history so that when merge is complete,
+        # phoenix is the selected row.
+        self.uistate.set_active(phoenix.get_handle(), 'Note')
         self.close()
