@@ -41,13 +41,14 @@ from gi.repository import Gtk
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
-from gramps.gen.lib.placetype import PlaceType
+from gramps.gen.lib import Place, PlaceType
 from gramps.gen.datehandler import format_time
 from gramps.gen.utils.place import conv_lat_lon
-from gramps.gen.constfunc import cuni
+from gramps.gen.display.place import displayer as place_displayer
+from gramps.gen.config import config
 from .flatbasemodel import FlatBaseModel
 from .treebasemodel import TreeBaseModel
 
@@ -64,7 +65,7 @@ _ = glocale.translation.gettext
 # PlaceBaseModel
 #
 #-------------------------------------------------------------------------
-class PlaceBaseModel(object):
+class PlaceBaseModel:
 
     def __init__(self, db):
         self.gen_cursor = db.get_place_cursor
@@ -80,7 +81,8 @@ class PlaceBaseModel(object):
             self.column_private,
             self.column_tags,
             self.column_change,
-            self.column_tag_color
+            self.column_tag_color,
+            self.search_name,
             ]
         self.smap = [
             self.column_name,
@@ -93,7 +95,8 @@ class PlaceBaseModel(object):
             self.column_private,
             self.column_tags,
             self.sort_change,
-            self.column_tag_color
+            self.column_tag_color,
+            self.search_name,
             ]
 
     def destroy(self):
@@ -116,10 +119,23 @@ class PlaceBaseModel(object):
         return len(self.fmap)+1
 
     def column_title(self, data):
-        return cuni(data[2])
+        handle = data[0]
+        cached, value = self.get_cached_value(handle, "PLACE")
+        if not cached:
+            place = Place()
+            place.unserialize(data)
+            value = place_displayer.display(self.db, place)
+            self.set_cached_value(handle, "PLACE", value)
+        return value
 
     def column_name(self, data):
-        return cuni(data[6])
+        """ Return the primary name """
+        return data[6][0]
+
+    def search_name(self, data):
+        """ The search name includes all alt names to enable finding by alt name
+        """
+        return ','.join([data[6][0]] + [name[0] for name in data[7]])
 
     def column_longitude(self, data):
         if not data[3]:
@@ -127,7 +143,7 @@ class PlaceBaseModel(object):
         value = conv_lat_lon('0', data[3], format='DEG')[1]
         if not value:
             return _("Error in format")
-        return value
+        return ("\u202d" + value + "\u202e") if glocale.rtl_locale else value
 
     def column_latitude(self, data):
         if not data[4]:
@@ -135,7 +151,7 @@ class PlaceBaseModel(object):
         value = conv_lat_lon(data[4], '0', format='DEG')[0]
         if not value:
             return _("Error in format")
-        return value
+        return ("\u202d" + value + "\u202e") if glocale.rtl_locale else value
 
     def sort_longitude(self, data):
         if not data[3]:
@@ -151,16 +167,16 @@ class PlaceBaseModel(object):
         value = conv_lat_lon(data[4], '0', format='ISO-DMS') if data[4] else ''
         if not value:
             return _("Error in format")
-        return value 
+        return value
 
     def column_id(self, data):
-        return cuni(data[1])
+        return data[1]
 
     def column_type(self, data):
         return str(PlaceType(data[8]))
 
     def column_code(self, data):
-        return cuni(data[9])
+        return data[9]
 
     def column_private(self, data):
         if data[17]:
@@ -168,10 +184,10 @@ class PlaceBaseModel(object):
         else:
             # There is a problem returning None here.
             return ''
-    
+
     def sort_change(self, data):
         return "%012x" % data[15]
-    
+
     def column_change(self, data):
         return format_time(data[15])
 
@@ -179,30 +195,60 @@ class PlaceBaseModel(object):
         """
         Return the tag name from the given tag handle.
         """
-        return self.db.get_tag_from_handle(tag_handle).get_name()
-        
+        cached, value = self.get_cached_value(tag_handle, "TAG_NAME")
+        if not cached:
+            value = self.db.get_tag_from_handle(tag_handle).get_name()
+            self.set_cached_value(tag_handle, "TAG_NAME", value)
+        return value
+
     def column_tag_color(self, data):
         """
         Return the tag color.
         """
-        tag_color = "#000000000000"
-        tag_priority = None
-        for handle in data[16]:
-            tag = self.db.get_tag_from_handle(handle)
-            if tag:
-                this_priority = tag.get_priority()
-                if tag_priority is None or this_priority < tag_priority:
-                    tag_color = tag.get_color()
-                    tag_priority = this_priority
-        return tag_color
+        tag_handle = data[0]
+        cached, value = self.get_cached_value(tag_handle, "TAG_COLOR")
+        if not cached:
+            tag_color = ""
+            tag_priority = None
+            for handle in data[16]:
+                tag = self.db.get_tag_from_handle(handle)
+                if tag:
+                    this_priority = tag.get_priority()
+                    if tag_priority is None or this_priority < tag_priority:
+                        tag_color = tag.get_color()
+                        tag_priority = this_priority
+            value = tag_color
+            self.set_cached_value(tag_handle, "TAG_COLOR", value)
+        return value
 
     def column_tags(self, data):
         """
         Return the sorted list of tags.
         """
         tag_list = list(map(self.get_tag_name, data[16]))
+        # TODO for Arabic, should the next line's comma be translated?
         return ', '.join(sorted(tag_list, key=glocale.sort_key))
 
+    def clear_cache(self, handle=None):
+        """
+        Clear the LRU cache. Always clear lru_path, because paths may have
+        changed.
+        Need special version of this because Places include Placerefs, and a
+        change in the place the Placeref points to can make the cache stale.
+        So just clearing the effected (deleted/changed) handle is not enough.
+        Note that this is only a (very) short term issue, during processing of
+        signals from a merge event.  The update of the place containing a
+        Placeref will occur.
+        See bug 10184.
+
+        Note that this method overrides the one from 'BaseModel', through
+        FlatBaseModel and TreeBaseModel.  By locating this in PlaceBaseModel,
+        the MRU rules mean this method takes precedence.
+        """
+        self.lru_data.clear()
+        # Invalidates all paths
+        self.lru_path.clear()
+
 #-------------------------------------------------------------------------
 #
 # PlaceListModel
@@ -212,12 +258,12 @@ class PlaceListModel(PlaceBaseModel, FlatBaseModel):
     """
     Flat place model.  (Original code in PlaceBaseModel).
     """
-    def __init__(self, db, scol=0, order=Gtk.SortType.ASCENDING, search=None,
-                 skip=set(), sort_map=None):
+    def __init__(self, db, uistate, scol=0, order=Gtk.SortType.ASCENDING,
+                 search=None, skip=set(), sort_map=None):
 
         PlaceBaseModel.__init__(self, db)
-        FlatBaseModel.__init__(self, db, scol, order, search=search, skip=skip,
-                               sort_map=sort_map)
+        FlatBaseModel.__init__(self, db, uistate, scol, order, search=search,
+                               skip=skip, sort_map=sort_map)
 
     def destroy(self):
         """
@@ -235,11 +281,11 @@ class PlaceTreeModel(PlaceBaseModel, TreeBaseModel):
     """
     Hierarchical place model.
     """
-    def __init__(self, db, scol=0, order=Gtk.SortType.ASCENDING, search=None,
-                 skip=set(), sort_map=None):
+    def __init__(self, db, uistate, scol=0, order=Gtk.SortType.ASCENDING,
+                 search=None, skip=set(), sort_map=None):
 
         PlaceBaseModel.__init__(self, db)
-        TreeBaseModel.__init__(self, db, scol=scol, order=order,
+        TreeBaseModel.__init__(self, db, uistate, scol=scol, order=order,
                                search=search, skip=skip, sort_map=sort_map,
                                nrgroups=3,
                                group_can_have_handle=True)
