@@ -5,6 +5,7 @@
 # Copyright (C) 2003-2005  Donald N. Allingham
 # Copyright (C) 2008       Stefan Siegel
 # Copyright (C) 2008       Brian G. Matherly
+# Copyright (C) 2021       Mirko Leonhaeuser
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,7 +26,7 @@
 # by Don Allingham and on valuable input from Dr. Martin Senftleben
 # Modified by Joachim Breitner to not use „Großcousine“, in accordance with
 # http://de.wikipedia.org/wiki/Verwandtschaftsbeziehung
-# Rewritten from scratch for GRAMPS 3 by Stefan Siegel,
+# Rewritten from scratch for Gramps 3 by Stefan Siegel,
 # loosely based on rel_fr.py
 """
 German-specific classes for relationships.
@@ -41,7 +42,7 @@ import re
 
 #-------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #-------------------------------------------------------------------------
 
@@ -156,7 +157,7 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
         if removed < len(_removed):
             return _removed[removed]
         else:
-            return '(%s)' % self._make_roman(removed-2)
+            return '(%s) Urgroß' % self._make_roman(removed-1)
 
     def _degree_text(self, degree, removed):
         if removed == 0:
@@ -201,7 +202,7 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
 
         if degree == 0 and removed < 0:
             # for descendants the "in-law" logic is reversed
-            (in_law_a, in_law_b) = (in_law_b, in_law_a) 
+            (in_law_a, in_law_b) = (in_law_b, in_law_a)
 
         rel_str = ''
         pre = ''
@@ -267,7 +268,7 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
                                              reltocommon_a, reltocommon_b,
                                              only_birth, in_law_a, in_law_b)
 
-    def get_sibling_relationship_string(self, sib_type, gender_a, gender_b, 
+    def get_sibling_relationship_string(self, sib_type, gender_a, gender_b,
                                         in_law_a=False, in_law_b=False):
         if sib_type in [self.NORM_SIB, self.UNKNOWN_SIB]:
             # the NORM_SIB translation is generic and suitable for UNKNOWN_SIB
@@ -291,11 +292,11 @@ class RelationshipCalculator(gramps.gen.relationship.RelationshipCalculator):
 if __name__ == "__main__":
     # Test function. Call it as follows from the command line (so as to find
     #        imported modules):
-    #    export PYTHONPATH=/path/to/gramps/src 
-    # python src/plugins/rel/rel_de.py 
+    #    export PYTHONPATH=/path/to/gramps/src
+    # python src/plugins/rel/rel_de.py
     # (Above not needed here)
 
-    """TRANSLATORS, copy this if statement at the bottom of your 
+    """TRANSLATORS, copy this if statement at the bottom of your
         rel_xx.py module, and test your work with:
         python src/plugins/rel/rel_xx.py
     """
