@@ -10,7 +10,7 @@
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
-# This program is distributed in the hope that it will be useful, 
+# This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
@@ -23,6 +23,10 @@
 """
 Debugging utilities
 """
+import cProfile
+import pstats
+import sys
+
 
 #-------------------------------------------------------------------------
 #
@@ -30,15 +34,13 @@ Debugging utilities
 #
 #-------------------------------------------------------------------------
 def profile(func, *args, **kwargs):
-    import hotshot.stats
 
-    prf = hotshot.Profile('mystats.profile')
+    prf = cProfile.Profile()
     print("Start")
     r = prf.runcall(func, *args, **kwargs)
     print("Finished")
-    prf.close()
     print("Loading profile")
-    stats = hotshot.stats.load('mystats.profile')
+    stats = pstats.Stats(prf, stream=sys.stdout)
     print("done")
     stats.strip_dirs()
     stats.sort_stats('time', 'calls')
@@ -50,7 +52,7 @@ def format_exception(tb_type=None, tb_value=None, tb=None):
     """
     Get the usual traceback information, followed by a listing of all the
     local variables in each frame.
-    Based on: 
+    Based on:
     code.activestate.com/recipes/52215-get-more-information-from-tracebacks
     """
     import sys
@@ -81,7 +83,7 @@ def format_exception(tb_type=None, tb_value=None, tb=None):
             #We have to be careful not to cause a new error in our error
             #handler! Calling str() on an unknown object could cause an
             #error we don't want.
-            try:                   
+            try:
                 line = "  %s = %s\n" % (key, str(value))
             except:
                 line = "  %s = %s\n" % (key, "<ERROR PRINTING VALUE>")
