@@ -20,7 +20,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #-------------------------------------------------------------------------
@@ -45,21 +45,30 @@ from gi.repository import Gdk
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
 _ = glocale.translation.sgettext
-from gramps.gen.constfunc import conv_to_unicode
 from ..utils import open_file_with_default_application
 from gramps.gen.const import THUMBSCALE
 from gramps.gen.mime import get_description, get_type
-from ..thumbnails import get_thumbnail_image, find_mime_type_pixbuf
+from gramps.gen.utils.thumbnails import get_thumbnail_image, find_mime_type_pixbuf
 from gramps.gen.utils.file import (media_path_full, find_file, create_checksum)
 from gramps.gen.lib import NoteType
 from gramps.gen.db import DbTxn
 from ..glade import Glade
-from .displaytabs import (CitationEmbedList, AttrEmbedList, MediaBackRefList, 
+from .displaytabs import (CitationEmbedList, MediaAttrEmbedList, MediaBackRefList,
                          NoteTab)
 from ..widgets import (MonitoredSpinButton, MonitoredEntry, PrivacyButton,
                        MonitoredDate, MonitoredTagList, SelectionWidget, Region)
 from .editreference import RefTab, EditReference
-from .addmedia import AddMediaObject
+from .addmedia import AddMedia
+from gramps.gen.const import URL_MANUAL_SECT2
+
+#-------------------------------------------------------------------------
+#
+# Constants
+#
+#-------------------------------------------------------------------------
+
+WIKI_HELP_PAGE = URL_MANUAL_SECT2
+WIKI_HELP_SEC = _('manual|Media_Reference_Editor_dialog')
 
 #-------------------------------------------------------------------------
 #
@@ -73,35 +82,36 @@ class EditMediaRef(EditReference):
                                media_ref, update)
         if not self.source.get_handle():
             #show the addmedia dialog immediately, with track of parent.
-            AddMediaObject(state, self.uistate, self.track, self.source, 
+            AddMedia(state, self.uistate, self.track, self.source,
                            self._update_addmedia)
 
     def _local_init(self):
-        self.width_key = 'interface.media-ref-width'
-        self.height_key = 'interface.media-ref-height'
-        self.top = Glade()
 
+        self.top = Glade()
         self.set_window(self.top.toplevel,
                         self.top.get_object('title'),
                         _('Media Reference Editor'))
+        self.setup_configs('interface.media-ref', 600, 450)
+
         self.define_warn_box(self.top.get_object("warn_box"))
         self.top.get_object("label427").set_text(_("Y coordinate|Y"))
         self.top.get_object("label428").set_text(_("Y coordinate|Y"))
 
-        tblref =  self.top.get_object('table50')
+        tblref = self.top.get_object('table50')
         self.notebook_ref = self.top.get_object('notebook_ref')
         self.track_ref_for_deletion("notebook_ref")
+        self.expander = self.top.get_object('expander1')
         #recreate start page as GrampsTab
         self.notebook_ref.remove_page(0)
-        self.reftab = RefTab(self.dbstate, self.uistate, self.track, 
+        self.reftab = RefTab(self.dbstate, self.uistate, self.track,
                               _('General'), tblref)
         self.track_ref_for_deletion("reftab")
-        tblref =  self.top.get_object('table2')
+        tblref = self.top.get_object('table2')
         self.notebook_shared = self.top.get_object('notebook_shared')
         #recreate start page as GrampsTab
         self.notebook_shared.remove_page(0)
         self.track_ref_for_deletion("notebook_shared")
-        self.primtab = RefTab(self.dbstate, self.uistate, self.track, 
+        self.primtab = RefTab(self.dbstate, self.uistate, self.track,
                               _('_General'), tblref)
         self.track_ref_for_deletion("primtab")
         self.rect_pixbuf = None
@@ -152,18 +162,18 @@ class EditMediaRef(EditReference):
             self.selection.load_image('')
 
     def _setup_fields(self):
-        
+
         ebox_shared = self.top.get_object('eventbox')
         ebox_shared.connect('button-press-event', self.button_press_event)
         self.pixmap = self.top.get_object("pixmap")
         self.mimetext = self.top.get_object("type")
         self.track_ref_for_deletion("mimetext")
-        
+
         coord = self.source_ref.get_rectangle()
         #upgrade path: set invalid (from eg old db) to none
 
         if coord is not None and coord in (
-                (None,)*4,  
+                (None,)*4,
                 (0, 0, 100, 100),
                 (coord[0], coord[1])*2
             ):
@@ -173,11 +183,12 @@ class EditMediaRef(EditReference):
             self.rectangle = coord
         else:
             self.rectangle = (0, 0, 100, 100)
-        
+
         self.selection = SelectionWidget()
         self.selection.set_multiple_selection(False)
         self.selection.connect("region-modified", self.region_modified)
         self.selection.connect("region-created", self.region_modified)
+        self.expander.connect("activate", self.selection.expander)
         frame = self.top.get_object("frame9")
         frame.add(self.selection)
         self.track_ref_for_deletion("selection")
@@ -185,7 +196,7 @@ class EditMediaRef(EditReference):
 
         self.setup_filepath()
         self.determine_mime()
-        
+
         corners = ["corner1_x", "corner1_y", "corner2_x", "corner2_y"]
 
         if coord and isinstance(coord, tuple):
@@ -194,11 +205,11 @@ class EditMediaRef(EditReference):
         else:
             for corner, value in zip(corners, [0, 0, 100, 100]):
                 self.top.get_object(corner).set_value(value)
-            
+
         if self.dbstate.db.readonly:
             for corner in corners:
                 self.top.get_object(corner).set_sensitive(False)
-        
+
         self.corner1_x_spinbutton = MonitoredSpinButton(
             self.top.get_object("corner1_x"),
             self.set_corner1_x,
@@ -254,18 +265,18 @@ class EditMediaRef(EditReference):
             self.source.set_path,
             self.source.get_path,
             self.db.readonly)
-            
+
         self.date_field = MonitoredDate(
             self.top.get_object("date_entry"),
             self.top.get_object("date_edit"),
             self.source.get_date_object(),
             self.uistate, self.track,
             self.db.readonly)
-            
+
         self.tags = MonitoredTagList(
-            self.top.get_object("tag_label"), 
-            self.top.get_object("tag_button"), 
-            self.source.set_tag_list, 
+            self.top.get_object("tag_label"),
+            self.top.get_object("tag_button"),
+            self.source.set_tag_list,
             self.source.get_tag_list,
             self.db,
             self.uistate, self.track,
@@ -283,10 +294,10 @@ class EditMediaRef(EditReference):
         Callback for the signal handling of the spinbutton for the first
         corner x coordinate of the subsection.
         Updates the subsection thumbnail using the given value
-        
+
         @param value: the first corner x coordinate of the subsection in int
         """
-        
+
         self.rectangle = (value,) + self.rectangle[1:]
         self.update_region()
 
@@ -295,10 +306,10 @@ class EditMediaRef(EditReference):
         Callback for the signal handling of the spinbutton for the first
         corner y coordinate of the subsection.
         Updates the subsection thumbnail using the given value
-        
+
         @param value: the first corner y coordinate of the subsection in int
         """
-        
+
         self.rectangle = self.rectangle[:1] + (value,) + self.rectangle[2:]
         self.update_region()
 
@@ -307,10 +318,10 @@ class EditMediaRef(EditReference):
         Callback for the signal handling of the spinbutton for the second
         corner x coordinate of the subsection.
         Updates the subsection thumbnail using the given value
-        
+
         @param value: the second corner x coordinate of the subsection in int
         """
-        
+
         self.rectangle = self.rectangle[:2] + (value,) + self.rectangle[3:]
         self.update_region()
 
@@ -319,29 +330,29 @@ class EditMediaRef(EditReference):
         Callback for the signal handling of the spinbutton for the second
         corner y coordinate of the subsection.
         Updates the subsection thumbnail using the given value
-        
+
         @param value: the second corner y coordinate of the subsection in int
         """
-        
+
         self.rectangle = self.rectangle[:3] + (value,)
         self.update_region()
 
     def get_corner1_x(self):
         """
-        Callback for the signal handling of the spinbutton for the first corner 
+        Callback for the signal handling of the spinbutton for the first corner
         x coordinate of the subsection.
-        
-        @returns: the first corner x coordinate of the subsection or 0 if 
+
+        @returns: the first corner x coordinate of the subsection or 0 if
                   there is no selection
         """
         return self.rectangle[0]
 
     def get_corner1_y(self):
         """
-        Callback for the signal handling of the spinbutton for the first corner 
+        Callback for the signal handling of the spinbutton for the first corner
         y coordinate of the subsection.
-        
-        @returns: the first corner y coordinate of the subsection or 0 if 
+
+        @returns: the first corner y coordinate of the subsection or 0 if
                   there is no selection
         """
         return self.rectangle[1]
@@ -350,8 +361,8 @@ class EditMediaRef(EditReference):
         """
         Callback for the signal handling of the spinbutton for the second
         corner x coordinate of the subsection.
-        
-        @returns: the second corner x coordinate of the subsection or 100 if 
+
+        @returns: the second corner x coordinate of the subsection or 100 if
                   there is no selection
         """
         return self.rectangle[2]
@@ -360,8 +371,8 @@ class EditMediaRef(EditReference):
         """
         Callback for the signal handling of the spinbutton for the second
         corner x coordinate of the subsection.
-        
-        @returns: the second corner x coordinate of the subsection or 100 if 
+
+        @returns: the second corner x coordinate of the subsection or 100 if
                   there is no selection
         """
         return self.rectangle[3]
@@ -375,6 +386,7 @@ class EditMediaRef(EditReference):
         real = self.selection.proportional_to_real_rect(self.rectangle)
         region = Region(real[0], real[1], real[2], real[3])
         self.selection.set_regions([region])
+        self.selection.select(region)  # update the selection box shown
         self.selection.refresh()
 
     def region_modified(self, widget):
@@ -398,11 +410,12 @@ class EditMediaRef(EditReference):
         else:
             submenu_label = _('New Media')
         return (_('Media Reference Editor'),submenu_label)
-    
+
     def button_press_event(self, obj, event):
-        if event.button==1 and event.type == Gdk.EventType._2BUTTON_PRESS:
+        if (event.type == Gdk.EventType.DOUBLE_BUTTON_PRESS
+                and event.button == 1):
             photo_path = media_path_full(self.db, self.source.get_path())
-            open_file_with_default_application(photo_path)
+            open_file_with_default_application(photo_path, self.uistate)
 
     def _update_addmedia(self, obj):
         """
@@ -415,7 +428,7 @@ class EditMediaRef(EditReference):
         self.determine_mime()
         self.update_checksum()
         self.draw_preview()
-        
+
     def update_checksum(self):
         self.uistate.set_busy_cursor(True)
         media_path = media_path_full(self.dbstate.db, self.source.get_path())
@@ -425,17 +438,20 @@ class EditMediaRef(EditReference):
     def select_file(self, val):
         self.determine_mime()
         path = self.file_path.get_text()
-        self.source.set_path(conv_to_unicode(path))
-        AddMediaObject(self.dbstate, self.uistate, self.track, self.source, 
+        self.source.set_path(path)
+        AddMedia(self.dbstate, self.uistate, self.track, self.source,
                        self._update_addmedia)
 
     def _connect_signals(self):
         self.define_cancel_button(self.top.get_object('button84'))
         self.define_ok_button(self.top.get_object('button82'),self.save)
+        # TODO help button (rename glade button name)
+        self.define_help_button(self.top.get_object('button104'),
+                WIKI_HELP_PAGE, WIKI_HELP_SEC)
 
     def _connect_db_signals(self):
         """
-        Connect any signals that need to be connected. 
+        Connect any signals that need to be connected.
         Called by the init routine of the base class (_EditPrimary).
         """
         self._add_db_signal('media-rebuild', self.close)
@@ -459,7 +475,7 @@ class EditMediaRef(EditReference):
         self._add_tab(notebook_ref, self.srcref_list)
         self.track_ref_for_deletion("srcref_list")
 
-        self.attr_list = AttrEmbedList(self.dbstate,self.uistate,self.track,
+        self.attr_list = MediaAttrEmbedList(self.dbstate,self.uistate,self.track,
                                        self.source_ref.get_attribute_list())
         self._add_tab(notebook_ref, self.attr_list)
         self.track_ref_for_deletion("attr_list")
@@ -479,12 +495,12 @@ class EditMediaRef(EditReference):
 
         self.src_srcref_list = CitationEmbedList(self.dbstate,
                                              self.uistate,
-                                             self.track, 
+                                             self.track,
                                              self.source.get_citation_list())
         self._add_tab(notebook_src, self.src_srcref_list)
         self.track_ref_for_deletion("src_srcref_list")
 
-        self.src_attr_list = AttrEmbedList(self.dbstate,self.uistate,self.track,
+        self.src_attr_list = MediaAttrEmbedList(self.dbstate,self.uistate,self.track,
                                            self.source.get_attribute_list())
         self._add_tab(notebook_src, self.src_attr_list)
         self.track_ref_for_deletion("src_attr_list")
@@ -504,13 +520,13 @@ class EditMediaRef(EditReference):
         if self.source.handle:
             with DbTxn(_("Edit Media Object (%s)") %
                        self.source.get_description(), self.db) as trans:
-                self.db.commit_media_object(self.source, trans)
+                self.db.commit_media(self.source, trans)
         else:
             if self.check_for_duplicate_id('Media'):
                 return
-            with DbTxn(_("Add Media Object (%s)") % 
+            with DbTxn(_("Add Media Object (%s)") %
                        self.source.get_description(), self.db) as trans:
-                self.db.add_object(self.source, trans)
+                self.db.add_media(self.source, trans)
 
         #save reference object in memory
         coord = (
@@ -523,7 +539,7 @@ class EditMediaRef(EditReference):
         #do not set unset or invalid coord
 
         if coord is not None and coord in (
-                (None,)*4,  
+                (None,)*4,
                 (0, 0, 100, 100),
                 (coord[0], coord[1])*2
             ):
