@@ -1,10 +1,10 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
-# Copyright (C) 2008-2009  Brian G. Matherly
+# Copyright (C) 2008-2012  Brian G. Matherly
 # Copyright (C) 2009       Rob G. Healey <robhealey1@gmail.com>
 # Copyright (C) 2010       Jakim Friant
-# Copyright (C) 2012-2013  Paul Franklin
+# Copyright (C) 2012-2014  Paul Franklin
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
 #------------------------------------------------------------------------
@@ -30,7 +30,7 @@ import datetime, time
 
 #------------------------------------------------------------------------
 #
-# GRAMPS modules
+# Gramps modules
 #
 #------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
@@ -44,11 +44,11 @@ from gramps.gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
                                     FONT_SERIF, PARA_ALIGN_RIGHT,
                                     PARA_ALIGN_LEFT, PARA_ALIGN_CENTER,
                                     IndexMark, INDEX_TYPE_TOC)
-from gramps.gen.plug.menu import (BooleanOption, StringOption, NumberOption, 
+from gramps.gen.plug.menu import (BooleanOption, StringOption, NumberOption,
                                   EnumeratedListOption, FilterOption,
                                   PersonOption)
 from gramps.gen.plug.report import Report
-from gramps.gen.plug.report import utils as ReportUtils
+from gramps.gen.plug.report import utils
 from gramps.gen.plug.report import MenuReportOptions
 from gramps.gen.plug.report import stdoptions
 from gramps.gen.utils.alive import probably_alive
@@ -56,15 +56,16 @@ from gramps.gen.utils.alive import probably_alive
 import gramps.plugins.lib.libholiday as libholiday
 
 # localization for BirthdayOptions only!!
-from gramps.gen.datehandler import displayer as _dd
+from gramps.gen.datehandler import displayer as date_displayer
 
+# _T_ is a gramps-defined keyword -- see po/update_po.py and po/genpot.sh
 def _T_(value): # enable deferred translations (see Python docs 22.1.3.4)
     return value
-# _T_ is a gramps-defined keyword -- see po/update_po.py and po/genpot.sh
 
 _TITLE0 = _T_("Birthday and Anniversary Report")
 _TITLE1 = _T_("My Birthday Report")
 _TITLE2 = _T_("Produced with Gramps")
+_DEADTXT = _T_("✝")
 
 #------------------------------------------------------------------------
 #
@@ -74,6 +75,9 @@ _TITLE2 = _T_("Produced with Gramps")
 class BirthdayReport(Report):
     """
     Create the BirthdayReport object that produces the report.
+
+    name_format   - Preferred format to display names
+    incl_private  - Whether to include private data
     """
     def __init__(self, database, options, user):
         Report.__init__(self, database, options, user)
@@ -81,37 +85,39 @@ class BirthdayReport(Report):
         menu = options.menu
         mgobn = lambda name:options.menu.get_option_by_name(name).get_value()
 
+        stdoptions.run_private_data_option(self, menu)
+        # (this report has its own "living people" option ("alive") already)
+
         self.titletext = mgobn('titletext')
         self.relationships = mgobn('relationships')
         self.year = mgobn('year')
         self.country = mgobn('country')
-        self.anniversaries = mgobn('anniversaries')
-        self.start_dow = mgobn('start_dow')
         self.maiden_name = mgobn('maiden_name')
         self.alive = mgobn('alive')
         self.birthdays = mgobn('birthdays')
+        self.anniversaries = mgobn('anniversaries')
+        self.death_anniversaries = mgobn('death_anniversaries')
         self.text1 = mgobn('text1')
         self.text2 = mgobn('text2')
         self.text3 = mgobn('text3')
-        self.filter_option =  menu.get_option_by_name('filter')
+        self.deadtxt = mgobn('deadtxt')
+        self.filter_option = menu.get_option_by_name('filter')
         self.filter = self.filter_option.get_filter()
+        self.showyear = mgobn('showyear')
         pid = mgobn('pid')
-        
-        lang = menu.get_option_by_name('trans').get_value()
-        self._locale = self.set_locale(lang)
 
-        name_format = menu.get_option_by_name("name_format").get_value()
-        if name_format != 0:
-            self._name_display.set_default_format(name_format)
-        
-        self.center_person = database.get_person_from_gramps_id(pid)
-        if (self.center_person == None) :
-            raise ReportError(_("Person %s is not in the Database") % pid )
+        self.set_locale(menu.get_option_by_name('trans').get_value())
+
+        stdoptions.run_name_format_option(self, menu)
+
+        self.center_person = self.database.get_person_from_gramps_id(pid)
+        if self.center_person is None:
+            raise ReportError(_("Person %s is not in the Database") % pid)
 
     def get_name(self, person, maiden_name = None):
-        """ 
-        Return person's name, unless maiden_name given, unless married_name 
-        listed. 
+        """
+        Return person's name, unless maiden_name given, unless married_name
+        listed.
         """
         # Get all of a person's names:
         primary_name = person.get_primary_name()
@@ -148,7 +154,7 @@ class BirthdayReport(Report):
         holiday_table.load_holidays(self.year, country)
         for month in range(1, 13):
             for day in range(1, 32):
-                holiday_names = holiday_table.get_holidays(month, day) 
+                holiday_names = holiday_table.get_holidays(month, day)
                 for holiday_name in holiday_names:
                     self.add_day_item(self._(holiday_name), month, day)
                     # FIXME translation only works for a limited set of things
@@ -176,12 +182,15 @@ class BirthdayReport(Report):
         # get data from database:
         self.collect_data()
         # generate the report:
-        self.doc.start_paragraph('BIR-Title') 
+        self.doc.start_paragraph('BIR-Title')
         if self.titletext == _(_TITLE0):
-            title = self._(_TITLE0) + ": " + str(self.year)
+            title = self._("%(str1)s: %(str2)s") % {
+                'str1' : self._(_TITLE0),
+                'str2' : self._get_date(Date(self.year))} # localized year
         else:
-            title = str(self.titletext) + ": " + str(self.year)
-        # FIXME those concatenated strings won't work for RTL languages
+            title = self._("%(str1)s: %(str2)s") % {
+                'str1' : str(self.titletext),
+                'str2' : self._get_date(Date(self.year))}
         mark = IndexMark(title, INDEX_TYPE_TOC, 1)
         self.doc.write_text(title, mark)
         self.doc.end_paragraph()
@@ -206,13 +215,13 @@ class BirthdayReport(Report):
         if self.relationships:
             name = self.center_person.get_primary_name()
             self.doc.start_paragraph('BIR-Text3style')
-            mark = ReportUtils.get_person_mark(self.database,
+            mark = utils.get_person_mark(self.database,
                                                self.center_person)
             # feature request 2356: avoid genitive form
             self.doc.write_text(self._("Relationships shown are to %s") %
                                 self._name_display.display_name(name), mark)
             self.doc.end_paragraph()
-        with self._user.progress(_('Birthday and Anniversary Report'), 
+        with self._user.progress(_('Birthday and Anniversary Report'),
                 _('Formatting months...'), 12) as step:
             for month in range(1, 13):
                 step()
@@ -233,7 +242,7 @@ class BirthdayReport(Report):
             if thisday.month == month:
                 list = self.calendar.get(month, {}).get(thisday.day, [])
                 for p, p_obj in list:
-                    mark = ReportUtils.get_person_mark(self.database, p_obj)
+                    mark = utils.get_person_mark(self.database, p_obj)
                     p = p.replace("\n", " ")
                     if thisday not in started_day:
                         self.doc.start_paragraph("BIR-Daystyle")
@@ -251,21 +260,18 @@ class BirthdayReport(Report):
         and text.
         """
         people = self.database.iter_person_handles()
-        with self._user.progress(_('Birthday and Anniversary Report'), 
-                                  _('Applying Filter...'), 
-                                  self.database.get_number_of_people()) as step:
-            people = self.filter.apply(self.database, people, 
-                                       step)
-        
+        people = self.filter.apply(self.database, people, user=self._user)
+
+        ngettext = self._locale.translation.ngettext # to see "nearby" comments
         rel_calc = get_relationship_calculator(reinit=True,
                                                clocale=self._locale)
-        ngettext = self._locale.translation.ngettext # to see "nearby" comments
 
-        with self._user.progress(_('Birthday and Anniversary Report'), 
+        with self._user.progress(_('Birthday and Anniversary Report'),
                 _('Reading database...'), len(people)) as step:
             for person_handle in people:
                 step()
                 person = self.database.get_person_from_handle(person_handle)
+                short_name = self.get_name(person)
                 birth_ref = person.get_birth_ref()
                 birth_date = None
                 if birth_ref:
@@ -311,29 +317,37 @@ class BirthdayReport(Report):
                         comment = ""
                         if self.relationships:
                             relation = rel_calc.get_one_relationship(
-                                                             self.database, 
-                                                             self.center_person, 
+                                                             self.database,
+                                                             self.center_person,
                                                              person,
                                                              olocale=self._locale)
                             if relation:
                                 # FIXME this won't work for RTL languages
                                 comment = " --- %s" % relation
+                        deadtxt = ""
+                        if (not alive):
+                            deadtxt = self.deadtxt
+                        yeartxt = ""
+                        if self.showyear:
+                            yeartxt = "(%s) " % year
                         if nyears == 0:
-                            text = self._('%(person)s, birth%(relation)s') % {
+                            text = self._('* %(person)s, birth%(relation)s') % {
                                 'person'   : short_name,
                                 'relation' : comment}
                         else:
                             # translators: leave all/any {...} untranslated
-                            text = ngettext('{person}, {age}{relation}', 
-                                            '{person}, {age}{relation}',
-                                            nyears).format(person=short_name,
+                            text = ngettext('* {year}{person}{dead}, {age}{relation}',
+                                            '* {year}{person}{dead}, {age}{relation}',
+                                            nyears).format(year=yeartxt,
+                                                           person=short_name,
+                                                           dead=deadtxt,
                                                            age=nyears,
                                                            relation=comment)
 
                         self.add_day_item(text, month, day, person)
                 if self.anniversaries:
                     family_list = person.get_family_handle_list()
-                    for fhandle in family_list: 
+                    for fhandle in family_list:
                         fam = self.database.get_family_from_handle(fhandle)
                         father_handle = fam.get_father_handle()
                         mother_handle = fam.get_mother_handle()
@@ -348,15 +362,15 @@ class BirthdayReport(Report):
                                 spouse_name = self.get_name(spouse)
                                 short_name = self.get_name(person)
                                 # TEMP: this will handle ordered events
-                                # GRAMPS 3.0 will have a new mechanism for start/stop events
+                                # Gramps 3.0 will have a new mechanism for start/stop events
                                 are_married = None
                                 for event_ref in fam.get_event_ref_list():
                                     event = self.database.get_event_from_handle(event_ref.ref)
-                                    if event.type in [EventType.MARRIAGE, 
+                                    if event.type in [EventType.MARRIAGE,
                                                       EventType.MARR_ALT]:
                                         are_married = event
-                                    elif event.type in [EventType.DIVORCE, 
-                                                        EventType.ANNULMENT, 
+                                    elif event.type in [EventType.DIVORCE,
+                                                        EventType.ANNULMENT,
                                                         EventType.DIV_FILING]:
                                         are_married = None
                                 if are_married is not None:
@@ -371,24 +385,71 @@ class BirthdayReport(Report):
                                         nyears = self.year - year
 
                                         if event_obj.is_valid():
+                                            prob_alive_date = Date(self.year, month, day)
+                                            alive1 = probably_alive(person, self.database,
+                                                                        prob_alive_date)
+                                            alive2 = probably_alive(spouse, self.database,
+                                                                        prob_alive_date)
+                                            deadtxt1 = ""
+                                            deadtxt2 = ""
+                                            if (not alive1):
+                                                deadtxt1 = self.deadtxt
+                                            if (not alive2):
+                                                deadtxt2 = self.deadtxt
+                                            yeartxt = ""
+                                            if self.showyear:
+                                                yeartxt = "(%s) " % year
                                             if nyears == 0:
-                                                text = self._("%(spouse)s and\n %(person)s, wedding") % {
-                                                         'spouse' : spouse_name, 
+                                                text = self._("⚭ %(spouse)s and\n %(person)s, wedding") % {
+                                                         'spouse' : spouse_name,
                                                          'person' : short_name}
                                             else:
                                                 # translators: leave all/any {...} untranslated
-                                                text = ngettext("{spouse} and\n {person}, {nyears}",
-                                                                "{spouse} and\n {person}, {nyears}",
-                                                                nyears).format(spouse=spouse_name, person=short_name, nyears=nyears)
-     
-                                                prob_alive_date = Date(self.year, month, day)
-                                                alive1 = probably_alive(person, self.database,
-                                                                        prob_alive_date)
-                                                alive2 = probably_alive(spouse, self.database,
-                                                                        prob_alive_date)
+                                                text = ngettext("⚭ {year}{spouse}{deadtxt2} and\n {person}{deadtxt1}, {nyears}",
+                                                                "⚭ {year}{spouse}{deadtxt2} and\n {person}{deadtxt1}, {nyears}",
+                                                                nyears).format(year=yeartxt, spouse=spouse_name, deadtxt2=deadtxt2, person=short_name, deadtxt1=deadtxt1, nyears=nyears)
                                                 if (self.alive and alive1 and alive2) or not self.alive:
                                                     self.add_day_item(text, month, day, spouse)
 
+                death_ref = person.get_death_ref()
+                death_date = None
+                if death_ref:
+                    death_event = self.database.get_event_from_handle(death_ref.ref)
+                    death_date = death_event.get_date_object()
+
+                if (self.death_anniversaries and death_date is not None and death_date.is_valid()):
+                    death_date = gregorian(death_date)
+
+                    year = death_date.get_year()
+                    month = death_date.get_month()
+                    day = death_date.get_day()
+
+                    nyears = self.year - year
+
+                    comment = ""
+                    if self.relationships:
+                            relation = rel_calc.get_one_relationship(
+                                                             self.database,
+                                                             self.center_person,
+                                                             person,
+                                                             olocale=self._locale)
+                            if relation:
+                                # FIXME this won't work for RTL languages
+                                comment = " --- %s" % relation
+                    yeartxt = ""
+                    if self.showyear:
+                        yeartxt = "(%s) " % year
+                    if nyears == 0:
+                        text = _('✝ {person}, death {relation}').format(person=short_name,relation=comment)
+                    else:
+                        text = ngettext('✝ {year}{person}, {age}{relation}',
+                                        '✝ {year}{person}, {age}{relation}',
+                                        nyears).format(year=yeartxt,
+                                                       person=short_name,
+                                                       age=nyears,
+                                                       relation=comment)
+                    self.add_day_item(text, month, day, person)
+
 #------------------------------------------------------------------------
 #
 # BirthdayOptions
@@ -401,85 +462,31 @@ class BirthdayOptions(MenuReportOptions):
         self.__pid = None
         self.__filter = None
         MenuReportOptions.__init__(self, name, dbase)
-    
+
+    def get_subject(self):
+        """ Return a string that describes the subject of the report. """
+        return self.__filter.get_filter().get_name()
+
     def add_menu_options(self, menu):
         """ Add the options for the text birthday report """
         category_name = _("Report Options")
 
-        year = NumberOption(_("Year of report"), time.localtime()[0], 
-                            1000, 3000)
-        year.set_help(_("Year of report"))
-        menu.add_option(category_name, "year", year)
-
         self.__filter = FilterOption(_("Filter"), 0)
         self.__filter.set_help(
-               _("Select filter to restrict people that appear on report"))
+            _("Select the filter to be applied to the report."))
         menu.add_option(category_name, "filter", self.__filter)
-        
-        self.__pid = PersonOption(_("Center Person"))
-        self.__pid.set_help(_("The center person for the report"))
+        self.__filter.connect('value-changed', self.__filter_changed)
+
+        self.__pid = PersonOption(_("Filter Person"))
+        self.__pid.set_help(_("The center person for the filter."))
         menu.add_option(category_name, "pid", self.__pid)
         self.__pid.connect('value-changed', self.__update_filters)
-        
-        self.__update_filters()
 
-        stdoptions.add_name_format_option(menu, category_name)
-
-        country = EnumeratedListOption(_("Country for holidays"), 0)
-        holiday_table = libholiday.HolidayTable()
-        countries = holiday_table.get_countries()
-        countries.sort()
-        if (len(countries) == 0 or 
-            (len(countries) > 0 and countries[0] != '')):
-            countries.insert(0, '')
-        count = 0
-        for c in  holiday_table.get_countries():
-            country.add_item(count, c)
-            count += 1
-        country.set_help(_("Select the country to see associated holidays"))
-        menu.add_option(category_name, "country", country)
-
-        start_dow = EnumeratedListOption(_("First day of week"), 1)
-        long_days = _dd.long_days
-        for count in range(1, 8):
-            # conversion between gramps numbering (sun=1) and iso numbering (mon=1) of weekdays below
-            start_dow.add_item((count+5) % 7 + 1, long_days[count].capitalize()) 
-        start_dow.set_help(_("Select the first day of the week for the report"))
-        menu.add_option(category_name, "start_dow", start_dow) 
-
-        maiden_name = EnumeratedListOption(_("Birthday surname"), "own")
-        maiden_name.add_item("spouse_first", _("Wives use husband's surname (from first family listed)"))
-        maiden_name.add_item("spouse_last", _("Wives use husband's surname (from last family listed)"))
-        maiden_name.add_item("own", _("Wives use their own surname"))
-        maiden_name.set_help(_("Select married women's displayed surname"))
-        menu.add_option(category_name, "maiden_name", maiden_name)
-
-        alive = BooleanOption(_("Include only living people"), True)
-        alive.set_help(_("Include only living people in the report"))
-        menu.add_option(category_name, "alive", alive)
-
-        birthdays = BooleanOption(_("Include birthdays"), True)
-        birthdays.set_help(_("Include birthdays in the report"))
-        menu.add_option(category_name, "birthdays", birthdays)
-
-        anniversaries = BooleanOption(_("Include anniversaries"), True)
-        anniversaries.set_help(_("Include anniversaries in the report"))
-        menu.add_option(category_name, "anniversaries", anniversaries)
-        
-        option = BooleanOption(_("Include relationships to center person"), 
-                               False)
-        option.set_help(_("Include relationships to center person (slower)"))
-        menu.add_option(category_name, "relationships", option)
-
-        stdoptions.add_localization_option(menu, category_name)
-
-        category_name = _("Text Options")
-        
         titletext = StringOption(_("Title text"), _(_TITLE0))
         titletext.set_help(_("Title of report"))
         menu.add_option(category_name, "titletext", titletext)
 
-        text1 = StringOption(_("Text Area 1"), _(_TITLE1)) 
+        text1 = StringOption(_("Text Area 1"), _(_TITLE1))
         text1.set_help(_("First line of text at bottom of report"))
         menu.add_option(category_name, "text1", text1)
 
@@ -490,19 +497,107 @@ class BirthdayOptions(MenuReportOptions):
         text3 = StringOption(_("Text Area 3"), URL_HOMEPAGE,)
         text3.set_help(_("Third line of text at bottom of report"))
         menu.add_option(category_name, "text3", text3)
-        
+
+        category_name = _("Report Options (2)")
+
+        self._nf = stdoptions.add_name_format_option(menu, category_name)
+        self._nf.connect('value-changed', self.__update_filters)
+
+        stdoptions.add_private_data_option(menu, category_name)
+
+        alive = BooleanOption(_("Include only living people"), True)
+        alive.set_help(_("Include only living people in the report"))
+        menu.add_option(category_name, "alive", alive)
+
+        deadtxt = StringOption(_("Dead Symbol"), _(_DEADTXT))
+        deadtxt.set_help(_("This will show after name to indicate that person is dead"))
+        menu.add_option(category_name, "deadtxt", deadtxt)
+
+        self.__update_filters()
+
+        stdoptions.add_localization_option(menu, category_name)
+
+        showyear = BooleanOption(_("Show event year"), True)
+        showyear.set_help(_("Prints the year the event took place in the report"))
+        menu.add_option(category_name, "showyear", showyear)
+
+        category_name = _("Content")
+
+        year = NumberOption(_("Year of report"), time.localtime()[0],
+                            1000, 3000)
+        year.set_help(_("Year of report"))
+        menu.add_option(category_name, "year", year)
+
+        country = EnumeratedListOption(_("Country for holidays"), 0)
+        holiday_table = libholiday.HolidayTable()
+        countries = holiday_table.get_countries()
+        countries.sort()
+        if (len(countries) == 0 or
+            (len(countries) > 0 and countries[0] != '')):
+            countries.insert(0, '')
+        count = 0
+        for c in countries:
+            country.add_item(count, c)
+            count += 1
+        country.set_help(_("Select the country to see associated holidays"))
+        menu.add_option(category_name, "country", country)
+
+        maiden_name = EnumeratedListOption(_("Birthday surname"), "own")
+        maiden_name.add_item(
+            "spouse_first",
+            _("Wives use husband's surname (from first family listed)"))
+        maiden_name.add_item(
+            "spouse_last",
+            _("Wives use husband's surname (from last family listed)"))
+        maiden_name.add_item("own", _("Wives use their own surname"))
+        maiden_name.set_help(_("Select married women's displayed surname"))
+        menu.add_option(category_name, "maiden_name", maiden_name)
+
+        birthdays = BooleanOption(_("Include birthdays"), True)
+        birthdays.set_help(_("Whether to include birthdays"))
+        menu.add_option(category_name, "birthdays", birthdays)
+
+        anniversaries = BooleanOption(_("Include anniversaries"), True)
+        anniversaries.set_help(_("Whether to include anniversaries"))
+        menu.add_option(category_name, "anniversaries", anniversaries)
+
+        death_anniversaries = BooleanOption(_("Include death anniversaries"), True)
+        death_anniversaries.set_help(_("Whether to include anniversaries of death"))
+        menu.add_option(category_name, "death_anniversaries", death_anniversaries)
+
+        show_relships = BooleanOption(
+            _("Include relationship to center person"), False)
+        show_relships.set_help(
+            _("Whether to include relationships to the center person"))
+        menu.add_option(category_name, "relationships", show_relships)
+
     def __update_filters(self):
         """
         Update the filter list based on the selected person
         """
         gid = self.__pid.get_value()
         person = self.__db.get_person_from_gramps_id(gid)
-        filter_list = ReportUtils.get_person_filters(person, False)
+        nfv = self._nf.get_value()
+        filter_list = utils.get_person_filters(person,
+                                               include_single=False,
+                                               name_format=nfv)
         self.__filter.set_filters(filter_list)
 
-    def make_my_style(self, default_style, name, description, 
-                      size=9, font=FONT_SERIF, justified ="left", 
-                      color=None, align=PARA_ALIGN_CENTER, 
+    def __filter_changed(self):
+        """
+        Handle filter change. If the filter is not specific to a person,
+        disable the person option
+        """
+        filter_value = self.__filter.get_value()
+        if filter_value == 0: # "Entire Database" (as "include_single=False")
+            self.__pid.set_available(False)
+        else:
+            # The other filters need a center person (assume custom ones too)
+            self.__pid.set_available(True)
+
+    def make_my_style(self, default_style, name, description,
+                      size=9, font=FONT_SERIF, justified ="left",
+                      color=None, align=PARA_ALIGN_CENTER,
                       shadow = None, italic=0, bold=0, borders=0, indent=None):
         """ Create paragraph and graphic styles of the same name """
         # Paragraph:
@@ -522,11 +617,11 @@ class BirthdayOptions(MenuReportOptions):
         if indent:
             p.set(first_indent=indent)
         if justified == "left":
-            p.set_alignment(PARA_ALIGN_LEFT)       
+            p.set_alignment(PARA_ALIGN_LEFT)
         elif justified == "right":
-            p.set_alignment(PARA_ALIGN_RIGHT)       
+            p.set_alignment(PARA_ALIGN_RIGHT)
         elif justified == "center":
-            p.set_alignment(PARA_ALIGN_CENTER)       
+            p.set_alignment(PARA_ALIGN_CENTER)
         default_style.add_paragraph_style(name, p)
         # Graphics:
         g = GraphicsStyle()
@@ -538,22 +633,22 @@ class BirthdayOptions(MenuReportOptions):
         if not borders:
             g.set_line_width(0)
         default_style.add_draw_style(name, g)
-        
+
     def make_default_style(self, default_style):
         """ Add the styles used in this report """
-        self.make_my_style(default_style, "BIR-Title", 
-                           _('Title text style'), 14, 
+        self.make_my_style(default_style, "BIR-Title",
+                           _('Title text style'), 14,
                            bold=1, justified="center")
-        self.make_my_style(default_style, "BIR-Datastyle", 
+        self.make_my_style(default_style, "BIR-Datastyle",
                            _('Data text display'), 12, indent=1.0)
-        self.make_my_style(default_style, "BIR-Daystyle", 
-                           _('Day text style'), 12, indent=.5, 
+        self.make_my_style(default_style, "BIR-Daystyle",
+                           _('Day text style'), 12, indent=.5,
                            italic=1, bold=1)
-        self.make_my_style(default_style, "BIR-Monthstyle", 
+        self.make_my_style(default_style, "BIR-Monthstyle",
                            _('Month text style'), 14, bold=1)
-        self.make_my_style(default_style, "BIR-Text1style", 
+        self.make_my_style(default_style, "BIR-Text1style",
                            _('Text at bottom, line 1'), 12, justified="center")
-        self.make_my_style(default_style, "BIR-Text2style", 
+        self.make_my_style(default_style, "BIR-Text2style",
                            _('Text at bottom, line 2'), 12, justified="center")
-        self.make_my_style(default_style, "BIR-Text3style", 
+        self.make_my_style(default_style, "BIR-Text3style",
                            _('Text at bottom, line 3'), 12, justified="center")
