@@ -1,7 +1,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2001-2006  Donald N. Allingham
-# Copyright (C) 2008       Gary Burton 
+# Copyright (C) 2008       Gary Burton
 # Copyright (C) 2011       Tim G L Lyons
 #
 # This program is free software; you can redistribute it and/or modify
@@ -62,7 +62,7 @@ from gramps.gui.merge import MergeCitation
 #
 #-------------------------------------------------------------------------
 from gramps.gen.const import GRAMPS_LOCALE as glocale
-_ = glocale.translation.gettext
+_ = glocale.translation.sgettext
 
 
 #-------------------------------------------------------------------------
@@ -73,26 +73,26 @@ _ = glocale.translation.gettext
 class CitationListView(ListView):
     """
     A list view of citations.
-    
-    The citation list view only shows the citations (it does not show 
+
+    The citation list view only shows the citations (it does not show
     sources as separate list entries).
     """
     # The data items here have to correspond, in order, to the items in
     # src/giu/views/treemodels/citationlismodel.py
-    COL_TITLE_PAGE     =  0
-    COL_ID             =  1
-    COL_DATE           =  2
-    COL_CONFIDENCE     =  3
-    COL_PRIV           =  4
-    COL_TAGS           =  5
-    COL_CHAN           =  6
-    COL_SRC_TITLE      =  7
-    COL_SRC_ID         =  8
-    COL_SRC_AUTH       =  9
-    COL_SRC_ABBR       = 10
-    COL_SRC_PINFO      = 11
-    COL_SRC_PRIV       = 12
-    COL_SRC_CHAN       = 13
+    COL_TITLE_PAGE = 0
+    COL_ID = 1
+    COL_DATE = 2
+    COL_CONFIDENCE = 3
+    COL_PRIV = 4
+    COL_TAGS = 5
+    COL_CHAN = 6
+    COL_SRC_TITLE = 7
+    COL_SRC_ID = 8
+    COL_SRC_AUTH = 9
+    COL_SRC_ABBR = 10
+    COL_SRC_PINFO = 11
+    COL_SRC_PRIV = 12
+    COL_SRC_CHAN = 13
     # column definitions
     COLUMNS = [
         (_('Volume/Page'), TEXT, None),
@@ -116,11 +116,11 @@ class CitationListView(ListView):
                              COL_CONFIDENCE]),
         ('columns.rank', [COL_TITLE_PAGE, COL_ID, COL_DATE, COL_CONFIDENCE,
                           COL_PRIV, COL_TAGS, COL_CHAN, COL_SRC_TITLE,
-                          COL_SRC_ID, COL_SRC_AUTH, COL_SRC_ABBR, COL_SRC_PINFO, 
+                          COL_SRC_ID, COL_SRC_AUTH, COL_SRC_ABBR, COL_SRC_PINFO,
                           COL_SRC_PRIV, COL_SRC_CHAN]),
-        ('columns.size', [200, 75, 100, 100, 40, 100, 100, 200, 75, 75, 100, 
+        ('columns.size', [200, 75, 100, 100, 40, 100, 100, 200, 75, 75, 100,
                           150, 40, 100])
-        )    
+        )
     ADD_MSG = _("Add a new citation and a new source")
     ADD_SOURCE_MSG = _("Add a new source")
     ADD_CITATION_MSG = _("Add a new citation to an existing source")
@@ -140,127 +140,224 @@ class CitationListView(ListView):
             }
 
         ListView.__init__(
-            self, _('Citation View'), pdata, dbstate, uistate, 
+            self, _('Citation View'), pdata, dbstate, uistate,
             CitationListModel, signal_map,
             CitationBookmarks, nav_group,
             multiple=True,
             filter_class=CitationSidebarFilter)
 
-        self.func_list.update({
-            '<PRIMARY>J' : self.jump,
-            '<PRIMARY>BackSpace' : self.key_delete,
-            })
-
-        self.additional_uis.append(self.additional_ui())
+        self.additional_uis.append(self.additional_ui)
 
     def navigation_type(self):
         return 'Citation'
 
     def drag_info(self):
         return DdTargets.CITATION_LINK
-    
-    def define_actions(self):
-        """
-        This defines the possible actions for the citation views.
-        Possible actions are:
-        add:        Add a new citation and a new source (this can also be done 
-                      by source view add a source, then citation view add a new 
-                      citation to an existing source)
-        edit:       Edit a citation.
-        merge:      Merge the selected citations.
-        remove:     Delete the selected citations.
-        
-        
-        """
-        ListView.define_actions(self)
-
-        self.all_action = Gtk.ActionGroup(name=self.title + "/CitationAll")
-        self.edit_action = Gtk.ActionGroup(name=self.title + "/CitationEdit")
-
-        self._add_action('FilterEdit', None, _('Citation Filter Editor'),
-                         callback=self.filter_editor,)
-        self._add_action('QuickReport', None, _("Quick View"), None, None, None)
-
-        self._add_action_group(self.edit_action)
-        self._add_action_group(self.all_action)
 
     def get_stock(self):
         return 'gramps-citation'
 
-    def additional_ui(self):
-        """
-        Defines the UI string for UIManager
-        """
-        return '''<ui>
-          <menubar name="MenuBar">
-            <menu action="FileMenu">
-              <placeholder name="LocalExport">
-                <menuitem action="ExportTab"/>
-              </placeholder>
-            </menu>
-            <menu action="BookMenu">
-              <placeholder name="AddEditBook">
-                <menuitem action="AddBook"/>
-                <menuitem action="EditBook"/>
-              </placeholder>
-            </menu>
-            <menu action="GoMenu">
-              <placeholder name="CommonGo">
-                <menuitem action="Back"/>
-                <menuitem action="Forward"/>
-                <separator/>
-              </placeholder>
-            </menu>
-            <menu action="EditMenu">
-              <placeholder name="CommonEdit">
-                <menuitem action="Add"/>
-                <menuitem action="Edit"/>
-                <menuitem action="Remove"/>
-                <menuitem action="Merge"/>
-              </placeholder>
-              <menuitem action="FilterEdit"/>
-            </menu>
-          </menubar>
-          <toolbar name="ToolBar">
-            <placeholder name="CommonNavigation">
-              <toolitem action="Back"/>  
-              <toolitem action="Forward"/>  
-            </placeholder>
-            <placeholder name="CommonEdit">
-              <toolitem action="Add"/>
-              <toolitem action="Edit"/>
-              <toolitem action="Remove"/>
-              <toolitem action="Merge"/>
-            </placeholder>
-          </toolbar>
-          <popup name="Popup">
-            <menuitem action="Back"/>
-            <menuitem action="Forward"/>
-            <separator/>
-            <menuitem action="Add"/>
-            <menuitem action="Edit"/>
-            <menuitem action="Remove"/>
-            <menuitem action="Merge"/>
-            <separator/>
-            <menu name="QuickReport" action="QuickReport"/>
-          </popup>
-        </ui>'''
+    additional_ui = [
+        '''
+      <placeholder id="LocalExport">
+        <item>
+          <attribute name="action">win.ExportTab</attribute>
+          <attribute name="label" translatable="yes">Export View...</attribute>
+        </item>
+      </placeholder>
+''',
+        '''
+      <section id="AddEditBook">
+        <item>
+          <attribute name="action">win.AddBook</attribute>
+          <attribute name="label" translatable="yes">_Add Bookmark</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.EditBook</attribute>
+          <attribute name="label" translatable="no">%s...</attribute>
+        </item>
+      </section>
+''' % _('Organize Bookmarks'),
+        '''
+      <placeholder id="CommonGo">
+      <section>
+        <item>
+          <attribute name="action">win.Back</attribute>
+          <attribute name="label" translatable="yes">_Back</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Forward</attribute>
+          <attribute name="label" translatable="yes">_Forward</attribute>
+        </item>
+      </section>
+      </placeholder>
+''',
+        '''
+      <section id='CommonEdit' groups='RW'>
+        <item>
+          <attribute name="action">win.Add</attribute>
+          <attribute name="label" translatable="yes">_Add...</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Edit</attribute>
+          <attribute name="label">%s</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Remove</attribute>
+          <attribute name="label" translatable="yes">_Delete</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Merge</attribute>
+          <attribute name="label" translatable="yes">_Merge...</attribute>
+        </item>
+      </section>
+''' % _("action|_Edit..."),  # to use sgettext()
+        '''
+        <placeholder id='otheredit'>
+        <item>
+          <attribute name="action">win.FilterEdit</attribute>
+          <attribute name="label" translatable="yes">'''
+        '''Citation Filter Editor</attribute>
+        </item>
+        </placeholder>
+''',  # Following are the Toolbar items
+        '''
+    <placeholder id='CommonNavigation'>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-previous</property>
+        <property name="action-name">win.Back</property>
+        <property name="tooltip_text" translatable="yes">'''
+        '''Go to the previous object in the history</property>
+        <property name="label" translatable="yes">_Back</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RO'>
+      <object class="GtkToolButton">
+        <property name="icon-name">go-next</property>
+        <property name="action-name">win.Forward</property>
+        <property name="tooltip_text" translatable="yes">'''
+        '''Go to the next object in the history</property>
+        <property name="label" translatable="yes">_Forward</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+''',
+        '''
+    <placeholder id='BarCommonEdit'>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">list-add</property>
+        <property name="action-name">win.Add</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">_Add...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">gtk-edit</property>
+        <property name="action-name">win.Edit</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">Edit...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">list-remove</property>
+        <property name="action-name">win.Remove</property>
+        <property name="tooltip_text">%s</property>
+        <property name="label" translatable="yes">_Delete</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    <child groups='RW'>
+      <object class="GtkToolButton">
+        <property name="icon-name">gramps-merge</property>
+        <property name="action-name">win.Merge</property>
+        <property name="tooltip_text" >%s</property>
+        <property name="label" translatable="yes">_Merge...</property>
+        <property name="use-underline">True</property>
+      </object>
+      <packing>
+        <property name="homogeneous">False</property>
+      </packing>
+    </child>
+    </placeholder>
+''' % (ADD_MSG, EDIT_MSG, DEL_MSG, MERGE_MSG),
+        '''
+    <menu id="Popup">
+      <section>
+        <item>
+          <attribute name="action">win.Back</attribute>
+          <attribute name="label" translatable="yes">_Back</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Forward</attribute>
+          <attribute name="label" translatable="yes">Forward</attribute>
+        </item>
+      </section>
+      <section id="PopUpTree">
+      </section>
+      <section>
+        <item>
+          <attribute name="action">win.Add</attribute>
+          <attribute name="label" translatable="yes">_Add...</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Edit</attribute>
+          <attribute name="label">%s</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Remove</attribute>
+          <attribute name="label" translatable="yes">_Delete</attribute>
+        </item>
+        <item>
+          <attribute name="action">win.Merge</attribute>
+          <attribute name="label" translatable="yes">_Merge...</attribute>
+        </item>
+      </section>
+      <section>
+        <placeholder id='QuickReport'>
+        </placeholder>
+      </section>
+    </menu>
+''' % _('action|_Edit...')  # to use sgettext()
+]
 
-    def add(self, obj):
+    def add(self, *obj):
         """
-        add:        Add a new citation and a new source (this can also be done 
-                      by source view add a source, then citation view add a new 
+        add:        Add a new citation and a new source (this can also be done
+                      by source view add a source, then citation view add a new
                       citation to an existing source)
-        
-        Create a new Source instance and Citation instance and call the 
-        EditCitation editor with the new source and new citation. 
-        
-        Called when the Add button is clicked. 
-        If the window already exists (WindowActiveError), we ignore it. 
+
+        Create a new Source instance and Citation instance and call the
+        EditCitation editor with the new source and new citation.
+
+        Called when the Add button is clicked.
+        If the window already exists (WindowActiveError), we ignore it.
         This prevents the dialog from coming up twice on the same object.
-        
+
         However, since the window is identified by the Source object, and
-        we have just created a new one, it seems to be impossible for the 
+        we have just created a new one, it seems to be impossible for the
         window to already exist, so this is just an extra safety measure.
         """
         try:
@@ -269,18 +366,18 @@ class CitationListView(ListView):
         except WindowActiveError:
             pass
 
-    def remove(self, obj):
+    def remove(self, *obj):
         self.remove_selected_objects()
 
     def remove_object_from_handle(self, handle):
         the_lists = get_citation_referents(handle, self.dbstate.db)
         object = self.dbstate.db.get_citation_from_handle(handle)
-        query = DeleteCitationQuery(self.dbstate, self.uistate, object, 
+        query = DeleteCitationQuery(self.dbstate, self.uistate, object,
                                     the_lists)
         is_used = any(the_lists)
         return (query, is_used, object)
 
-    def edit(self, obj):
+    def edit(self, *obj):
         """
         Edit a Citation
         """
@@ -301,12 +398,12 @@ class CitationListView(ListView):
                     "the same citation is being edited.\n\nTo edit this "
                     "citation, you need to close the object.")
 
-    def merge(self, obj):
+    def merge(self, *obj):
         """
         Merge the selected citations.
         """
         mlist = self.selected_handles()
-        
+
         if len(mlist) != 2:
             msg = _("Cannot merge citations.")
             msg2 = _("Exactly two citations must be selected to perform a "
@@ -318,7 +415,7 @@ class CitationListView(ListView):
             citation1 = self.dbstate.db.get_citation_from_handle(mlist[0])
             citation2 = self.dbstate.db.get_citation_from_handle(mlist[1])
             if not citation1.get_reference_handle()  == \
-                            citation2.get_reference_handle():         
+                            citation2.get_reference_handle():
                 msg = _("Cannot merge citations.")
                 msg2 = _("The two selected citations must have the same "
                          "source to perform a merge. If you want to merge "
@@ -326,7 +423,8 @@ class CitationListView(ListView):
                          "sources first.")
                 ErrorDialog(msg, msg2, parent=self.uistate.window)
             else:
-                MergeCitation(self.dbstate, self.uistate, mlist[0], mlist[1])
+                MergeCitation(self.dbstate, self.uistate, [], mlist[0],
+                              mlist[1])
 
     def get_handle_from_gramps_id(self, gid):
         obj = self.dbstate.db.get_citation_from_gramps_id(gid)
@@ -354,7 +452,7 @@ class CitationListView(ListView):
         citation = self.dbstate.db.get_citation_from_handle(citation_handle)
         citation.add_tag(tag_handle)
         self.dbstate.db.commit_citation(citation, transaction)
-        
+
     def get_default_gramplets(self):
         """
         Define the default gramplets for the sidebar and bottombar.
